Utility Examples
~~~~~~~~~~~~~~~~~~~~

pyrolite includes a range of utilities for everything from dealing with
the web to plotting, synthetic data and machine learning. While most of these
are used as part of the core functions of pyrolite, you may also find
other uses for them, and this section provides some simple examples for
some of these.
